@@ -6,7 +6,7 @@
 
 #pragma once
 
-#include <AkonadiCore/Tag>
+#include <Akonadi/Tag>
 
 namespace Akonadi
 {
@@ -42,4 +42,3 @@ private:
     Akonadi::Monitor *const mMonitor;
 };
 }
-
